@@ -30,7 +30,7 @@ class View_Start:
   public slots:
     void on_translate_clicked();
     void on_open_clicked();
-   // void on_camera_clicked();
+    void on_camera_clicked();
 
     //
     //  Dialog slots ( for select a picture )
